#!/usr/bin/python

import sys
import unittest


class TestLoader(unittest.TestLoader):
    """Custom TestLoader to extend the stock python one."""

    suiteClass = unittest.TestSuite

    def loadTestsFromModuleNames(self, names):
        result = self.suiteClass()
        for name in names:
            result.addTests(self.loadTestsFromModuleName(name))
        return result

    def loadTestsFromModuleName(self, name):
        result = self.suiteClass()
        __import__(name, globals(), locals(), [])
        module = sys.modules[name]

        result.addTests(self.loadTestsFromModule(module))
        return result


class TestProgram(unittest.TestProgram):

    def __init__(self, module='__main__'):
        # Tell unittest to call createTests
        unittest.TestProgram.__init__(self, module, testLoader=TestLoader(),
                                      # Tell unittest to call createTests
                                      defaultTest=True,
                                      )

    def createTests(self):
        suite = self.testLoader.suiteClass()

        std_tests = self.testLoader.loadTestsFromModule(self.module)
        suite.addTests(std_tests)
        suite.addTests(self.testLoader.loadTestsFromModuleNames([
                    'udd.tests.test_categorise_failures',
                    'udd.tests.test_circuit_breaker',
                    'udd.tests.test_commit_database',
                    'udd.tests.test_config',
                    'udd.tests.test_count_outstanding_jobs',
                    'udd.tests.test_email_failures',
                    'udd.tests.test_graph_failures',
                    'udd.tests.test_helpers',
                    'udd.tests.test_history_database',
                    'udd.tests.test_icommon',
                    'udd.tests.test_idb',
                    'udd.tests.test_import_list',
                    'udd.tests.test_import_package',
                    'udd.tests.test_list_packages',
                    'udd.tests.test_logrotate',
                    'udd.tests.test_lpapi',
                    'udd.tests.test_package_database',
                    'udd.tests.test_package_to_import',
                    'udd.tests.test_mass_import',
                    'udd.tests.test_revid_database',
                    'udd.tests.test_status_database',
                    'udd.tests.test_threads',
                    ]))
        self.test = suite


if __name__ == '__main__':
    TestProgram(module=__name__)
