from storm.locals import create_database, Store


def get_sqlite_connection_string(config, db_name):
    if db_name == 'main':
        path = config.get('pi.sqlite_file')
    elif db_name == 'package':
        path = config.get('pi.sqlite_package_file')
    elif db_name == 'history':
        path = config.get('pi.sqlite_history_file')
    else:
        raise AssertionError("Unknown db_name: %s" % db_name)
    return 'sqlite:%s' % path


def get_postgres_connection_string(config, db_name):
    db_host = config.get('pi.postgres_host')
    db_port = config.get('pi.postgres_port')
    db_user = config.get('pi.postgres_user')
    db_password = config.get('pi.postgres_password')
    db_database = config.get('pi.postgres_database')
    return 'postgres://%s:%s@%s:%s/%s' % (
                db_user, db_password, db_host,
                db_port, db_database)


def get_connection_string(config, db_name):
    db_type = config.get('pi.db_type')
    if db_type == 'sqlite':
        conn_str = get_sqlite_connection_string(config, db_name)
    elif db_type == 'postgres':
        conn_str = get_postgres_connection_string(config, db_name)
    else:
        raise AssertionError("Unknown db_type: %s" % db_type)
    return conn_str, db_type


def get_db_connection(config, db_name):
    conn_str, db_type = get_connection_string(config, db_name)
    database = create_database(conn_str)
    return Store(database), db_type


def get_memory_db_connection():
    return Store(create_database("sqlite:")), "sqlite"
