"""
Script to create local branches from all existing official package branches
of a package, for debugging purposes.
"""

import optparse
import os
import sys
from bzrlib import branch, bzrdir, tag, trace, transport, ui

from udd import icommon
from udd import lpapi


def handle_series(distribution, series, package):
    sp = series.getSourcePackage(name=package)
    for pocket in icommon.distro_pockets[distribution.name]:
        local_name = os.path.join(package, distribution.name + "-" +
                icommon.make_suite(series.name, pocket))
        series_branch = sp.getBranch(pocket=pocket.title())
        if series_branch is None:
            continue
        if os.path.exists(local_name):
            trace.note("%s: already exists locally" % (local_name,))
            continue
        from_br = branch.Branch.open("bzr+ssh://bazaar.launchpad.net/" +
                series_branch.unique_name)
        trace.note("Branching %s from %s" % (local_name, from_br.base))
        to_dir = from_br.bzrdir.sprout(local_name, source_branch=from_br)
        to_br = to_dir.open_branch()
        tag._merge_tags_if_possible(from_br, to_br)


def main():
    lp = lpapi.get_lp()
    parser = optparse.OptionParser()
    options, args = parser.parse_args()
    trace.enable_default_logging()
    ui.ui_factory = ui.make_ui_for_terminal(sys.stdin, sys.stdout, sys.stderr)
    for package in args:
        format = bzrdir.format_registry.make_bzrdir('default')
        to_transport = transport.get_transport(package)
        to_transport.ensure_base()
        newdir = format.initialize_on_transport(to_transport)
        repo = newdir.create_repository(shared=True)
        repo.set_make_working_trees(False)
        for distribution_name in ("debian", "ubuntu"):
            distribution = lp.distributions[distribution_name]
            for series in distribution.series:
                handle_series(distribution, series, package)
