"""
Script to delete all existing branches for a package from Launchpad, so that
an import can be retried from scratch. It takes care of clearing branch to
series source package links and branch to bug links to try to make branches
deleteable - though there are other kinds of linked objectss that are not
handled, and should not be automatically deleted in any case (e.g. merge
proposals).

Only branches having unique names of the style automatically created by the
importer are deleted - manually pushed branches which have since been linked
to a distribution series source package as the official branch will not be
touched.
"""

import optparse
from lazr.uri import URI

from udd import icommon
from udd import lpapi


def lp_delete(obj):
    obj._root._browser.delete(URI(obj.self_link))


def delete_series(lp, distribution, series, package):
    sp = series.getSourcePackage(name=package)
    for pocket in icommon.distro_pockets[distribution.name]:
        suite = icommon.make_suite(series.name, pocket)
        unique_name = "~ubuntu-branches/%s/%s/%s/%s" % (distribution.name, series.name, package, suite)
        branch = lp.branches.getByUniqueName(unique_name=unique_name)
        if branch is None:
            continue
        other_branch = sp.getBranch(pocket=pocket.title())
        if other_branch is not None and other_branch.unique_name == branch.unique_name:
            print "Unlinking %s from series" % unique_name
            sp.setBranch(branch=None, pocket=pocket.title())
        for bug in branch.linked_bugs:
            print "Unlinking %s from %s" % (bug.id, unique_name)
            branch.unlinkBug(bug=bug)
        if not branch.canBeDeleted():
            print "%s can't be deleted" % unique_name
            continue
        print "Deleting %s" % branch.self_link
        #branch.lp_delete()
        lp_delete(branch)


def main():
    lp = lpapi.get_lp()
    parser = optparse.OptionParser()
    options, args = parser.parse_args()
    for package in args:
        for distribution_name in ("debian", "ubuntu"):
            distribution = lp.distributions[distribution_name]
            for series in reversed(distribution.series):
                delete_series(lp, distribution, series, package)
