import sys

from udd import (
    icommon,
    iconfig,
    idb,
    )


# Not ideal to declare this here but this is used by several local functions
# below. Refactoring the whole script may help -- vila 2011-12-07
conf = None # Will be set by main()


def write_email(failures):
    text = ""
    for package, reason, when_failed in failures:
        if reason == icommon.running_sentinel:
            continue
        text += "\n\n%s failed at %s due to:\n%s\n" % (
            package, when_failed, reason.encode("ascii", "replace"))
    return text


def only_main(failures):
    db = icommon.PackageDatabase(*idb.get_db_connection(conf, 'package'))
    main_packages = db.list_packages_in_main()
    filtered = []
    for failure in failures:
        package = failure[0]
        if package in main_packages:
            filtered.append(failure)
    return filtered


def email_failures():
    db = icommon.StatusDatabase(*idb.get_db_connection(conf, 'main'))
    failures = db.unemailed_failures()
    failures = only_main(failures)
    if failures:
        content = write_email(failures)
        print content
        db.set_failures_emailed(failures)


def main():
    global conf
    conf = iconfig.ImporterStack()
    lock = icommon.lock_path(conf.get('pi.script_locks_dir'), 'email_failures')
    if lock is None:
        print "Another instance of email_failures is already running."
        sys.exit(0)
    try:
        email_failures()
    finally:
        lock.close()
