from udd import (
    icommon,
    iconfig,
    idb,
    )


def find_info_where(package_info, clause):
    ret = []
    for info in package_info:
        if clause(info):
            ret.append(info)
    return ret


def get_info(conf):
    db = icommon.StatusDatabase(*idb.get_db_connection(conf, 'main'))
    return db.summarise_failures()[1]


def update_failed_counts(package_info, cb):
    outstanding = find_info_where(package_info, lambda x: x.queued)
    running = find_info_where(package_info, lambda x: x.running)
    failed = len(package_info) - len(outstanding) - len(running)
    cb(len(outstanding), failed)


def get_main_packages(conf):
    db = icommon.PackageDatabase(*idb.get_db_connection(conf, 'package'))
    return db.list_packages_in_main()


def filter_packages(filter_set, package_info):
    return find_info_where(package_info, lambda x: x.name in filter_set)


def main():
    conf =  iconfig.ImporterStack()
    package_info = get_info(conf)
    db = icommon.HistoryDatabase(*idb.get_db_connection(conf, 'history'))
    update_failed_counts(package_info, db.set_counts)
    main_packages = get_main_packages(conf)
    main_package_info = filter_packages(main_packages, package_info)
    update_failed_counts(main_package_info, db.set_main_counts)
