"""Get a list of packages from Launchpad and store them in the local database."""

import datetime
import sys

from launchpadlib.errors import HTTPError

from udd import (
    icommon,
    iconfig,
    idb,
    lpapi,
    )


def main():
    conf = iconfig.ImporterStack()
    lock = icommon.lock_path(conf.get('pi.script_locks_dir'), 'list_packages')
    if lock is None:
        print "Another instance of list_packages is already running."
        sys.exit(0)
    try:
        lp = lpapi.get_lp()

        db = icommon.PackageDatabase(*idb.get_db_connection(conf, 'package'))

        last_update = db.last_update()
        if last_update is not None:
            last_update = last_update - datetime.timedelta(days=1)
            last_update = last_update.isoformat()

        distributions = conf.get('pi.distributions')

        for distro_name in distributions:
            distro = lp.distributions[distro_name]
            current_series_name = distro.current_series.name
            # The reason this queries each series individually is to avoid
            # requesting too much data at once, causing Launchpad to time out.
            for s in distro.series:
                series_name = s.name
                filters = {'since': last_update, 'series': series_name}
                publications = icommon.iter_publications(distro, **filters)
                for publication in publications:
                    packages = {}
                    if publication.name in packages:
                        continue
                    # Packages in the current series in the 'main' component
                    # are considered to be more important than the rest.
                    if (series_name == current_series_name and
                        publication.component_name == "main"):
                        packages[publication.name] = 1
                    else:
                        packages[publication.name] = 0
                    db.update_packages(packages)

    except HTTPError, e:
        sys.stderr.write(e.content + "\n")
        raise
    except KeyboardInterrupt, e:
        sys.stderr.write("KeyboardInterrupt\n")
        sys.exit(1)
    finally:
        lock.close()
