"""Invoke logrotate for the package importer taking configuration into account.
"""

import os
import subprocess

from udd import (
    icommon,
    iconfig,
    )

logrotate_configuration='''{pi.driver.log.debug} {
    daily
    dateext
    rotate 7
    delaycompress
    compress
    notifempty
    missingok
}

{pi.driver.log.progress} {
    daily
    dateext
    rotate 28
    delaycompress
    compress
    notifempty
    missingok
}
'''

def main():
    conf = iconfig.ImporterStack()

    log_dir = conf.get('pi.driver.log_dir')
    icommon.ensure_directory(log_dir)
    lrot_conf_path = os.path.join(log_dir, 'logrotate.conf')
    with open(lrot_conf_path, 'w') as f:
        f.write(conf.expand_options(logrotate_configuration))

    lrot_state_path = os.path.join(log_dir, 'logrotate.state')
    retcode = subprocess.call(['/usr/sbin/logrotate', '-s', lrot_state_path,
                               lrot_conf_path])
    return retcode
