from optparse import OptionParser
import sys

from udd import (
    icommon,
    iconfig,
    idb,
    )


def get_options():
    parser = OptionParser()
    parser.add_option("--full", dest="full", action="store_true",
            help="Also remove the revids: DANGEROUS")
    parser.add_option("--zap-revids", dest="zap_revids", action="store",
            help="Also remove the revids for a given comma-separated list of series "
            "(e.g. maverick,natty,oneiric): DANGEROUS (but less than --full)",
            default="")
    parser.add_option("--force", dest="force", action="store_true",
            help="Requeue even if it hasn't failed")
    parser.add_option("--priority", dest="priority", action="store_true",
            help="Requeue with a high priority")
    parser.add_option("--auto", dest="auto", action="store_true",
            help="Requeue this type of problem automatically from now on.")
    parser.add_option("--all-of-type", dest="all", action="store_true",
            help="Requeue all packages with this problem.")
    return parser


def main():
    parser = get_options()
    opts, args = parser.parse_args()

    errors = 0

    if len(args) < 1:
        print "Specify a list of packages to requeue"
        sys.exit(1)

    opts.zap_revids = filter(None, opts.zap_revids.split(','))

    conf = iconfig.ImporterStack()
    conn, db_type = idb.get_db_connection(conf, 'main')
    db = icommon.StatusDatabase(conn, db_type)

    for package in args:
        package = unicode(package)
        lock = icommon.lock_path(conf.get('pi.locks_dir'), package)
        if lock is None:
            print "Can't lock %s" % package
            errors += 1
            continue
        try:
            retried = db.retry(package, force=opts.force,
                               priority=opts.priority,
                               auto=opts.auto, all=opts.all)
            if not retried:
                print "%s has not failed" % package
                errors += 1
                continue
            elif opts.full:
                # FIXME: do this in one transaction somehow
                with icommon.Cursor(conn) as c:
                    c.execute('delete from %s where package=?'
                              % icommon.RevidDatabase.REVID_TABLE, (package,))
                    c.execute(icommon.CommitDatabase.COMMIT_TABLE_DELETE,
                              (package,))
                    c.execute(icommon.RevidDatabase.DELETE_WORKING, (package,))
            elif opts.zap_revids:
                # FIXME: do this in one transaction somehow
                with icommon.Cursor(conn) as c:
                    for suite in opts.zap_revids:
                        c.execute('delete from %s where package=? and suite=?'
                                  % icommon.RevidDatabase.REVID_TABLE,
                                  (package, suite))
                    c.execute(icommon.CommitDatabase.COMMIT_TABLE_DELETE,
                              (package,))
                    c.execute(icommon.RevidDatabase.DELETE_WORKING, (package,))
        finally:
            lock.close()
        if not opts.all:
            print "%s requeued" % package
        else:
            print "%s and all similar requeued" % package

    if errors > 0:
        sys.exit(1)
