import itertools
import os

from bzrlib import tests

from udd import iconfig

class TestCaseWithConfig(tests.TestCaseWithTransport):

    def setUp(self):
        super(TestCaseWithConfig, self).setUp()
        # Since iconfig states that pkgimport.conf is part of the sources (or a
        # directory below), we can't directly use this file for testing.
        # Instead, we override _root_dir to be local to the test
        self.overrideAttr(iconfig, '_root_dir', self.test_dir)
        content = 'pi.base_dir=%s\n' % (self.test_dir,)
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                content)

    def _set_store_content(self, store, content=None):
        # content may be unicode but the file content should be utf8
        content = content.encode('utf-8')
        store._load_from_string(content)
        store.save()

    def assertTestPathExists(self, relpath):
        self.assertPathExists(os.path.join(self.test_dir, relpath))


class Struct(object):
    """Create an object from a dict.

    The keys of the dict become our attributes, and the dict's values our
    values.
    """

    def __init__(self, **values):
        for key, value in values.items():
            setattr(self, key, value)
