import os

from bzrlib import (
    config,
    tests as bzr_tests,
    )


from udd import (
    iconfig,
    tests,
    )


class TestPackageStack(tests.TestCaseWithConfig):

    def test_package_option(self):
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                'foo=common\n[mypackage]\nfoo=package')
        self._set_store_content(config.LocationStore(),
                                '''[%s]\nfoo = location\n''' % self.test_dir)
        stack = iconfig.PackageStack('mypackage')
        # locations.conf is not taken into account here
        self.assertEquals('package', stack.get('foo'))

    def test_expanded_option_for_package(self):
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                '[mypackage]\nfoo={bar}\nbar=baz')
        stack = iconfig.PackageStack('mypackage')
        self.assertEquals('baz', stack.get('foo'))


class TestImporterStack(tests.TestCaseWithConfig):

    def test_subdir_takes_priority(self):
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                'foo=regular\n')
        os.mkdir('config')
        with open('config/pkgimport.conf', 'w') as f:
            f.write('foo=subdir\n')
        stack = iconfig.ImporterStack()
        self.assertEquals('subdir', stack.get('foo'))

    def test_common_option(self):
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                'foo=bar\n')
        stack = iconfig.ImporterStack()
        self.assertEquals('bar', stack.get('foo'))

    def test_overridden_in_locations(self):
        self._set_store_content(config.LocationStore(),
                                '''[%s]\nfoo = location\n''' % self.test_dir)
        stack = iconfig.ImporterStack()
        self.assertEquals('location', stack.get('foo'))

    def test_expanded_option_for_importer(self):
        self._set_store_content(iconfig.PkgimportStore(self.get_transport()),
                                'foo={bar}\nbar=baz')
        stack = iconfig.ImporterStack()
        self.assertEquals('baz', stack.get('foo'))


class TestDefaultConfigStack(bzr_tests.TestCaseWithTransport):
    """Test some significant options in the default configuration.

    No need to test them all, most of them are built on the same model.
    """

    def setUp(self):
        super(TestDefaultConfigStack, self).setUp()
        self.conf = iconfig.ImporterStack()

    # 'test_base_dir' is a TestCaseInTempDir attribute so it can't be used as a
    # test method name :-)
    def test_the_base_dir(self):
        self.assertEquals('/srv/package-import.canonical.com/new',
                          self.conf.get('pi.base_dir'))

    def test_log_dir(self):
        self.assertEquals('/srv/package-import.canonical.com/new/logs',
                          self.conf.get('pi.log_dir'))
