from udd import (
    iconfig,
    idb,
    tests,
    )


class SqliteConnectionStringTests(tests.TestCaseWithConfig):

    def test_get_sqlite_connection_string_main(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.sqlite_file=bar\n')
        stack = iconfig.ImporterStack()
        self.assertEquals('sqlite:bar',
                idb.get_sqlite_connection_string(stack, 'main'))

    def test_get_sqlite_connection_string_package(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.sqlite_package_file=baz\n')
        stack = iconfig.ImporterStack()
        self.assertEquals('sqlite:baz',
                idb.get_sqlite_connection_string(stack, 'package'))

    def test_get_sqlite_connection_string_history(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.sqlite_history_file=zap\n')
        stack = iconfig.ImporterStack()
        self.assertEquals('sqlite:zap',
                idb.get_sqlite_connection_string(stack, 'history'))


class PostgresConnectionStringTests(tests.TestCaseWithConfig):

    def test_get_postgres_connection_string(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.postgres_host=postgres_host\n' +
                            'pi.postgres_port=5692\n' +
                            'pi.postgres_user=postgres_user\n' +
                            'pi.postgres_password=postgres_password\n' +
                            'pi.postgres_database=postgres_database')
        stack = iconfig.ImporterStack()
        self.assertEquals(
                ('postgres://postgres_user:postgres_password'
                 '@postgres_host:5692/postgres_database'),
                idb.get_postgres_connection_string(stack, 'main'))


class GetConnectionStringTests(tests.TestCaseWithConfig):

    def test_get_connection_string_sqlite(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.db_type=sqlite\npi.sqlite_file=bar\n')
        stack = iconfig.ImporterStack()
        conn_str, db_type = idb.get_connection_string(stack, 'main')
        self.assertEquals('sqlite:bar', conn_str)
        self.assertEquals('sqlite', db_type)

    def test_get_connection_string_postgres(self):
        self._set_store_content(
                iconfig.PkgimportStore(self.get_transport()),
                            'pi.db_type=postgres\n')
        stack = iconfig.ImporterStack()
        conn_str, db_type = idb.get_connection_string(stack, 'main')
        self.assertEquals('postgres://None:None@None:None/None',
                conn_str)
        self.assertEquals('postgres', db_type)
