from datetime import datetime

from bzrlib.tests import TestCase

from udd.lpapi import Publication
from udd.tests import Struct


class TestPublication(TestCase):

    def make_publication(self, original):
        return Publication.from_source_or_binary(original)

    def test_source_package_name(self):
        spph = Struct(source_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(spph)
        self.assertEqual(spph.source_package_name, pub.name)

    def test_source_package_datetime(self):
        spph = Struct(source_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(spph)
        self.assertEqual(datetime(2011, 1, 1, 12, 34, 56), pub.published_time)

    def test_source_package_component_name(self):
        spph = Struct(source_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(spph)
        self.assertEqual(spph.component_name, pub.component_name)

    def test_binary_package_name(self):
        bpph = Struct(binary_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(bpph)
        self.assertEqual(bpph.binary_package_name, pub.name)

    def test_binary_package_datetime(self):
        bpph = Struct(binary_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(bpph)
        self.assertEqual(datetime(2011, 1, 1, 12, 34, 56), pub.published_time)

    def test_binary_package_component_name(self):
        bpph = Struct(binary_package_name='foo',
                      component_name='main',
                      date_created='2011-01-01 12:34:56')
        pub = self.make_publication(bpph)
        self.assertEqual(bpph.component_name, pub.component_name)
